package org.ofbiz.studentProgress;

import java.util.HashMap;
import java.util.Map;

import org.ofbiz.base.util.Debug;        // uses Log4J
import org.ofbiz.base.util.UtilMisc;     // helpful utility for working with Maps, Lists, etc.
import org.ofbiz.entity.GenericDelegator;
import org.ofbiz.entity.GenericEntityException;
import org.ofbiz.entity.GenericValue;
import org.ofbiz.service.DispatchContext;
import org.ofbiz.service.ServiceUtil;

public class MyServices {
    
    public static final String module = MyServices.class.getName(); // used for debugging
   
    public static Map createMyStudent(DispatchContext dctx, Map context) {
        GenericDelegator delegator = dctx.getDelegator();  // always passed in with DispatchContext        
        
        try {
            String studentId = delegator.getNextSeqId("MyStudent"); // gets next available key for MyStudent
            Debug.logInfo("myStudentId = " + studentId, module); // prints to the console or console.log
            GenericValue student = delegator.makeValue("MyStudent", 
                    UtilMisc.toMap("myStudentId", studentId)); // create a GenericValue from ID we just got
            student.setNonPKFields(context); // move non-primary key fields from input parameters to GenericValue
            delegator.create(student); // store the generic value, ie persists it
            
            Map result = ServiceUtil.returnSuccess(); // gets standard Map for successful service operations
            result.put("myStudentId", studentId); // puts output parameter into Map to return
            return result; // return Map
        } catch (GenericEntityException ex) { // required if you use delegator in Java
            return ServiceUtil.returnError(ex.getMessage());
        }
    }
}